function [turnCommand, speedCommand] = usvControlModule(currentLat, currentLon, currentSpeed, targetLat, targetLon)
    % 无人船控制模块
    % 输入参数：
    % currentLat, currentLon - 当前纬度和经度
    % currentSpeed - 当前速度
    % targetLat, targetLon - 目标纬度和经度
    
    % 定义速度和方向控制参数
    maxSpeed = 10; % 最大速度
    turnSensitivity = 0.5; % 转向灵敏度

    % 计算到目标的方向
    directionToTarget = atan2(targetLon - currentLon, targetLat - currentLat);

    % 基于方向差异计算转向命令
    turnCommand = turnSensitivity * directionToTarget;

    % 计算到目标的距离
    distanceToTarget = sqrt((targetLat - currentLat)^2 + (targetLon - currentLon)^2);

    % 基于距离计算速度命令
    if distanceToTarget > 1
        speedCommand = maxSpeed;
    else
        speedCommand = maxSpeed * distanceToTarget; % 减速接近目标
    end

    % 确保命令在合理范围内
    turnCommand = max(-1, min(1, turnCommand));
    speedCommand = max(0, min(maxSpeed, speedCommand));
    
    % 返回转向和速度命令
    return
end
